/**
 * Free Canvas
 *
 * @package    Free Canvas
 * @subpackage canvas.js
/*  Copyright (c) 2020- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

var can;
var ct;
var ox = 0,oy = 0,x = 0,y = 0;
var mf = false;
var brush_color = "#000000";
var brush_width = 5;

can = document.getElementById( free_canvas.name );
if ( can ) {
	can.addEventListener( "touchstart",onDown,false );
	can.addEventListener( "touchmove",onMove,false );
	can.addEventListener( "touchend",onUp,false );
	can.addEventListener( "mousedown",onMouseDown,false );
	can.addEventListener( "mousemove",onMouseMove,false );
	can.addEventListener( "mouseup",onMouseUp,false );
	ct = can.getContext( "2d" );
	ct.strokeStyle = brush_color;
	ct.lineWidth = brush_width;
	ct.lineJoin = "round";
	ct.lineCap = "round";
	clearCan();

	var select = document.getElementById( 'tool' );
	select.addEventListener(
		'change',
		function() {
			if ( select.value === 'brush' ) {
				canvasPencil();
			} else if ( select.value === 'eraser' ) {
				canvasEraser();
			}
		}
	);

}

function onDown(event){
	unsave_text();
	mf = true;
	ox = event.touches[0].pageX - event.target.getBoundingClientRect().left - scx();
	oy = event.touches[0].pageY - event.target.getBoundingClientRect().top - scy();
	event.stopPropagation()
}

function onMove(event){
	if (mf) {
		x = event.touches[0].pageX - event.target.getBoundingClientRect().left - scx();
		y = event.touches[0].pageY - event.target.getBoundingClientRect().top - scy();
		drawLine();
		ox = x;
		oy = y;
		event.preventDefault();
		event.stopPropagation();
	}
}

function onUp(event){
	mf = false;
	event.stopPropagation();
}

function onMouseDown(event){
	unsave_text();
	ox = event.clientX - event.target.getBoundingClientRect().left;
	oy = event.clientY - event.target.getBoundingClientRect().top;
	mf = true;
}

function onMouseMove(event){
	if (mf) {
		x = event.clientX - event.target.getBoundingClientRect().left;
		y = event.clientY - event.target.getBoundingClientRect().top;
		drawLine();
		ox = x;
		oy = y;
	}
}

function onMouseUp(event){
	mf = false;
}

function drawLine(){
	ct.strokeStyle = brush_color;
	ct.lineWidth = brush_width;
	ct.lineJoin = "round";
	ct.lineCap = "round";
	ct.beginPath();
	ct.moveTo( ox,oy );
	ct.lineTo( x,y );
	ct.stroke();
}

function clearCan(){
	unsave_text();
	ct.fillStyle = "rgb(255,255,255)";
	ct.fillRect( 0,0,can.getBoundingClientRect().width,can.getBoundingClientRect().height );
}

function scx(){return document.documentElement.scrollLeft || document.body.scrollLeft;}
function scy(){return document.documentElement.scrollTop || document.body.scrollTop;}

function canvasPencil(){
	brush_color = "#000000";
	brush_width = 5;
}

function canvasEraser(){
	brush_color = "#ffffff";
	brush_width = 20;
}

function unsave_text(){
	var elm1 = document.getElementById( 'free_canvas_save_text1' );
	var elm2 = document.getElementById( 'free_canvas_save_text2' );
	elm1.textContent = free_canvas.unsaved;
	elm1.style.color = 'red';
	elm2.textContent = free_canvas.unsaved;
	elm2.style.color = 'red';
}
