<?php
/**
 * Free Canvas
 *
 * @package    Free Canvas
 * @subpackage Free Canvas Main function
/*
	Copyright (c) 2020- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$freecanvas = new FreeCanvas();

/** ==================================================
 * Main Functions
 */
class FreeCanvas {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_shortcode( 'freecanvas', array( $this, 'freecanvas_func' ) );

	}

	/** ==================================================
	 * Short code
	 *
	 * @param array  $atts  attributes.
	 * @param string $content  contents.
	 * @return string $content  contents.
	 * @since 1.00
	 */
	public function freecanvas_func( $atts, $content = null ) {

		$a = shortcode_atts(
			array(
				'width'  => '',
				'height' => '',
				'name'   => '',
			),
			$atts
		);

		$settings_tbl = array(
			'width'  => 700,
			'height' => 700,
			'name'   => wp_date( 'YmdHis' ),
		);

		foreach ( $settings_tbl as $key => $value ) {
			$shortcodekey = strtolower( $key );
			if ( empty( $a[ $shortcodekey ] ) ) {
				$a[ $shortcodekey ] = $value;
			}
		}

		if ( is_singular() || is_admin() ) {

			wp_enqueue_script( 'canvas', plugin_dir_url( __DIR__ ) . 'js/canvas.js', array(), '1.00', false );
			wp_localize_script(
				'canvas',
				'free_canvas',
				array(
					'unsaved' => __( 'Unsaved', 'free-canvas' ),
					'name'    => $a['name'],
				)
			);

			$handle  = 'free-canvas-ajax-script';
			$action1 = 'free-canvas-ajax-action';
			wp_enqueue_script( $handle, plugin_dir_url( __DIR__ ) . 'js/jquery.freecanvas.ajax.js', array( 'jquery' ), '1.00', false );
			wp_localize_script(
				$handle,
				'FREECANVAS',
				array(
					'ajax_url'  => admin_url( 'admin-ajax.php' ),
					'action'    => $action1,
					'nonce'     => wp_create_nonce( $action1 ),
					'name'      => $a['name'],
					'saved_txt' => __( 'Saved', 'free-canvas' ),
				)
			);

			$content = '<div style="margin: auto;">';
			$content .= __( 'Select' ) . ' : ';
			$content .= '<select id="tool">';
			$content .= '<option value="brush">' . __( 'Pencil', 'free-canvas' ) . '</option>';
			$content .= '<option value="eraser">' . __( 'Eraser', 'free-canvas' ) . '</option>';
			$content .= '</select>';
			$content .= '<input type="button" onClick="clearCan();" value="' . __( 'Clear' ) . '" class="button-large" />';
			$content .= '<button name="FreeCanvasSave" id="FreeCanvasSave" class="button-large">' . __( 'Save' ) . '</button>';
			$content .= '<span id="free_canvas_save_text1" style="color: red;">' . __( 'Unsaved', 'free-canvas' ) . '</span>';
			$content .= '<div>';
			$content .= '<canvas id="' . $a['name'] . '" width="' . $a['width'] . '" height="' . $a['height'] . '" style="border: 1px solid #000000; background-color: white;"></canvas>';
			$content .= '</div>';
			$content .= '<input type="button" onClick="clearCan();" value="' . __( 'Clear' ) . '" class="button-large" />';
			$content .= '<button name="FreeCanvasSave" id="FreeCanvasSave" class="button-large">' . __( 'Save' ) . '</button>';
			$content .= '<span id="free_canvas_save_text2" style="color: red;">' . __( 'Unsaved', 'free-canvas' ) . '</span>';
			$content .= '</div>';

		} else {
			if ( is_archive() || is_home() ) {
				$content = null;
			}
		}

		return do_shortcode( $content );

	}

}


