<?php
/**
 * Free Canvas
 *
 * @package    Free Canvas
 * @subpackage FreeCanvasAdmin Management screen
	Copyright (c) 2020- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$freecanvasadmin = new FreeCanvasAdmin();

/** ==================================================
 * Management screen
 */
class FreeCanvasAdmin {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'admin_menu', array( $this, 'plugin_menu' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_custom_wp_admin_style' ) );
		add_filter( 'plugin_action_links', array( $this, 'settings_link' ), 10, 2 );

	}

	/** ==================================================
	 * Add a "Settings" link to the plugins page
	 *
	 * @param  array  $links  links array.
	 * @param  string $file   file.
	 * @return array  $links  links array.
	 * @since 1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty( $this_plugin ) ) {
			$this_plugin = 'free-canvas/freecanvas.php';
		}
		if ( $file === $this_plugin ) {
			$links[] = '<a href="' . admin_url( 'options-general.php?page=freecanvas' ) . '">' . __( 'Settings' ) . '</a>';
		}
			return $links;
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_menu() {
		add_options_page( 'Free Canvas Options', 'Free Canvas', 'manage_options', 'freecanvas', array( $this, 'plugin_options' ) );
	}

	/** ==================================================
	 * Add Css and Script
	 *
	 * @since 1.00
	 */
	public function load_custom_wp_admin_style() {
		if ( $this->is_my_plugin_screen() ) {
			wp_enqueue_style( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'css/responsive-tabs.css', array(), '1.4.0' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', plugin_dir_url( __DIR__ ) . 'css/style.css', array(), '1.4.0' );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ) . 'js/jquery.responsiveTabs.min.js', array(), '1.4.0', false );
			wp_enqueue_script( 'freecanvas-admin-js', plugin_dir_url( __DIR__ ) . 'js/jquery.freecanvas.admin.js', array( 'jquery' ), '1.0.0', false );
		}
	}

	/** ==================================================
	 * For only admin style
	 *
	 * @since 1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if ( is_object( $screen ) && 'settings_page_freecanvas' === $screen->id ) {
			return true;
		} else {
			return false;
		}
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function plugin_options() {

		if ( ! current_user_can( 'manage_options' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permissions to access this page.' ) );
		}

		$scriptname = admin_url( 'options-general.php?page=freecanvas' );

		?>

		<div class="wrap">
		<h2>Free Canvas</h2>

			<div id="freecanvas-admin-tabs">
				<ul>
					<li><a href="#freecanvas-admin-tabs-1"><?php esc_html_e( 'How to use', 'free-canvas' ); ?></a></li>
					<li><a href="#freecanvas-admin-tabs-2"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></a></li>
				</ul>

				<div id="freecanvas-admin-tabs-1">
					<div class="wrap">
						<h2><?php esc_html_e( 'How to use', 'free-canvas' ); ?></h2>	

						<div style="margin: 5px; padding: 5px;">
							<h3><?php esc_html_e( 'The following shortcode are provided.', 'free-canvas' ); ?></h3>
							<strong><code>freecanvas</code></strong>
							<div style="margin: 5px; padding: 5px;">
							<div><?php esc_html_e( 'Processing when the Save button of canvas is pressed.', 'free-canvas' ); ?></div>
							<table border=1 cellspacing="0" cellpadding="5" bordercolor="#000000" style="border-collapse: collapse">
							<tr>
							<td><strong><?php esc_html_e( 'Attribute', 'free-canvas' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Default' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Description' ); ?></strong></td>
							</tr>
							<tr>
							<td><strong>width</strong></td>
							<td><strong>700</strong></td>
							<td><strong><?php esc_html_e( 'Canvas width', 'free-canvas' ); ?></strong></td>
							</tr>
							<tr>
							<td><strong>height</strong></td>
							<td><strong>700</strong></td>
							<td><strong><?php esc_html_e( 'Canvas height', 'free-canvas' ); ?></strong></td>
							</tr>
							<tr>
							<td><strong>name</strong></td>
							<td><strong><?php esc_html_e( 'The date and time string when the canvas was loaded', 'free-canvas' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Unique name for this canvas', 'free-canvas' ); ?></strong></td>
							</tr>
							</table>
							</div>

							<h3><?php esc_html_e( 'The following filters are provided.', 'free-canvas' ); ?></h3>
							<strong><code>free_canvas_save</code></strong>
							<div style="margin: 5px; padding: 5px;">
							<div><?php esc_html_e( 'Processing when the Save button of canvas is pressed.', 'free-canvas' ); ?></div>
							<table border=1 cellspacing="0" cellpadding="5" bordercolor="#000000" style="border-collapse: collapse">
							<tr>
							<td><strong><?php esc_html_e( 'Variable', 'free-canvas' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Description' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'From', 'free-canvas' ); ?></strong></td>
							</tr>
							<tr>
							<td><strong>$image_data</strong></td>
							<td><strong><?php esc_html_e( 'PNG image data by Base64', 'free-canvas' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Value of Canvas', 'free-canvas' ); ?></strong></td>
							</tr>
							<tr>
							<td><strong>$name</strong></td>
							<td><strong><?php esc_html_e( 'Unique name for this canvas', 'free-canvas' ); ?></strong></td>
							<td><strong><?php esc_html_e( 'Value of Free Canvas', 'free-canvas' ); ?></strong></td>
							</tr>
							</table>
							</div>
							<h3><?php esc_html_e( 'Sample code', 'free-canvas' ); ?></h3>
							<div style="margin: 5px; padding: 5px;">
							<div><?php esc_html_e( 'This code outputs a PNG image file to the wp-content/uploads directory.', 'free-canvas' ); ?></div>
<textarea rows="17" cols="120" readonly>
/* Shortcode for canvas display */
echo do_shortcode('[freecanvas height=500]');
/* Filter hook */
add_filter( 'free_canvas_save', 'canvas_save', 10, 2 );
/* Function for outputs a PNG image file */
function canvas_save( $image_data, $name ) {
	$wp_uploads = wp_upload_dir();
	$relation_path_true = strpos( $wp_uploads['baseurl'], '../' );
	if ( $relation_path_true > 0 ) {
		$upload_dir = wp_normalize_path( realpath( $wp_uploads['basedir'] ) );
	} else {
		$upload_dir = wp_normalize_path( $wp_uploads['basedir'] );
	}
	$filename = $upload_dir . '/' . $name . '.png';
	$image = imagecreatefromstring( $image_data );
	imagepng( $image, $filename );
}
</textarea>
							</div>
						</div>

					</div>
				</div>

				<div id="freecanvas-admin-tabs-2">
					<div class="wrap">
					<?php $this->credit(); ?>
					</div>
				</div>

			</div>

		</div>
		<?php
	}

	/** ==================================================
	 * Credit
	 *
	 * @since 1.00
	 */
	private function credit() {

		$plugin_name    = null;
		$plugin_ver_num = null;
		$plugin_path    = plugin_dir_path( __DIR__ );
		$plugin_dir     = untrailingslashit( $plugin_path );
		$slugs          = explode( '/', $plugin_dir );
		$slug           = end( $slugs );
		$files          = scandir( $plugin_dir );
		foreach ( $files as $file ) {
			if ( '.' === $file || '..' === $file || is_dir( $plugin_path . $file ) ) {
				continue;
			} else {
				$exts = explode( '.', $file );
				$ext  = strtolower( end( $exts ) );
				if ( 'php' === $ext ) {
					$plugin_datas = get_file_data(
						$plugin_path . $file,
						array(
							'name'    => 'Plugin Name',
							'version' => 'Version',
						)
					);
					if ( array_key_exists( 'name', $plugin_datas ) && ! empty( $plugin_datas['name'] ) && array_key_exists( 'version', $plugin_datas ) && ! empty( $plugin_datas['version'] ) ) {
						$plugin_name    = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __( 'Version:' ) . ' ' . $plugin_ver_num;
		/* translators: FAQ Link & Slug */
		$faq       = sprintf( esc_html__( 'https://wordpress.org/plugins/%s/faq', '%s' ), $slug );
		$support   = 'https://wordpress.org/support/plugin/' . $slug;
		$review    = 'https://wordpress.org/support/view/plugin-reviews/' . $slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/' . $slug;
		$facebook  = 'https://www.facebook.com/katsushikawamori/';
		$twitter   = 'https://twitter.com/dodesyo312';
		$youtube   = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate    = sprintf( esc_html__( 'https://shop.riverforest-wp.info/donate/', '%s' ), $slug );

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo esc_html( $plugin_version ); ?> | 
		<a style="text-decoration: none;" href="<?php echo esc_url( $faq ); ?>" target="_blank"><?php esc_html_e( 'FAQ' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $support ); ?>" target="_blank"><?php esc_html_e( 'Support Forums' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $review ); ?>" target="_blank"><?php sprintf( esc_html_e( 'Reviews', '%s' ), $slug ); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo esc_url( $translate ); ?>" target="_blank">
		<?php
		/* translators: Plugin translation link */
		echo sprintf( esc_html__( 'Translations for %s' ), esc_html( $plugin_name ) );
		?>
		</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $facebook ); ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $twitter ); ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $youtube ); ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php sprintf( esc_html_e( 'Please make a donation if you like my work or would like to further the development of this plugin.', '%s' ), $slug ); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo esc_url( $donate ); ?>')"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></button>
		</div>

		<?php

	}

}


